agentle.agents.asgi.blacksheep.agent\_to\_blacksheep\_route\_handler\_adapter
=============================================================================

.. automodule:: agentle.agents.asgi.blacksheep.agent_to_blacksheep_route_handler_adapter

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
      cast
   
   .. rubric:: Classes

   .. autosummary::
   
      A2AInterface
      Adapter
      Agent
      AgentRunOutput
      AgentToBlackSheepRouteHandlerAdapter
      Any
      AssistantMessage
      BaseModel
      Controller
      DeveloperMessage
      FilePart
      Sequence
      Task
      TaskGetResult
      TaskQueryParams
      TaskSendParams
      TextPart
      Tool
      UserMessage
   